pub struct NormalizerOptions {
pub unify_in_list: bool,
pub unify_values: bool,
pub alphabetize_insert_columns: bool,
}Expand description
Toggles for normalize_with_options. Defaults to all false
(placeholder substitution only).
Fields
unify_in_list: boolUnify IN lists to a single form when all elements are literal values.
For example, IN (1, 2, 3) becomes IN (...).
unify_values: boolUnify VALUES lists to a single form when all elements are literal values.
For example, VALUES (1, 2, 3), (4, 5, 6) becomes VALUES (...).
alphabetize_insert_columns: boolAlphabetize column lists for INSERT statements with a VALUES expression
that gets unified.
For example, INSERT INTO t(c, b, a) becomes INSERT INTO t(a, b, c).
Implementations
Sourceimpl NormalizerOptions
impl NormalizerOptions
pub fn new() -> Self
pub fn with_unify_in_list(self, unify_in_list: bool) -> Self
pub fn with_unify_values(self, unify_values: bool) -> Self
pub fn with_alphabetize_insert_columns( self, alphabetize_insert_columns: bool, ) -> Self